@@ -9,14 +9,7 @@ from numpy import matrix
 
 from py_pol import degrees, eps
 from py_pol.stokes import Stokes
-
-
-"""
-PendingDeprecationWarning: the matrix subclass is not the recommended way to
-represent matrices or deal with linear algebra
-(see https://docs.scipy.org/doc/numpy/user/numpy-for-matlab-users.html).
-Please adjust your code to use regular ndarray.
-"""
+from py_pol.utils import comparison
 
 
 class TestStokes_parameters(object):
@@ -25,7 +18,7 @@ class TestStokes_parameters(object):
         # solution = matrix([[1], [0], [0], [0]])
         # M1 = Stokes('custom')
         # M1.custom(1, 0, 0, 0)
-        # proposal = M1.get()
-        # assert np.linalg.norm(proposal - solution) < eps, sys._getframe(
+        # proposal = M1.parameters.matrix()
+        # assert comparison(proposal, solution, eps), sys._getframe(
         # ).f_code.co_name + ".py --> example: (1, 0, 0, 0)"
         assert True
